@@ -1,4 +1,3 @@
-import py
 from cffi import FFI
 
 class FakeBackend(object):
@@ -26,6 +25,8 @@ class FakeBackend(object):
     def _get_types(self):
         return "CData", "CType"
 
+    buffer = "buffer type"
+
 
 class FakeType(object):
     def __init__(self, cdecl):
