@@ -1,5 +1,6 @@
 import py, os, sys, shutil
 import subprocess
+import textwrap
 from testing.udir import udir
 import pytest
 
@@ -13,13 +14,30 @@ if sys.version_info < (2, 7):
 def create_venv(name):
     tmpdir = udir.join(name)
     try:
+        # FUTURE: we should probably update this to use venv for at least more modern Pythons, and
+        # install setuptools/pip/etc explicitly for the tests that require them (as venv has stopped including
+        # setuptools and wheel by default for newer versions).
         subprocess.check_call(['virtualenv', 
             #'--never-download', <= could be added, but causes failures
             # in random cases on random machines
                                '-p', os.path.abspath(sys.executable),
                                str(tmpdir)])
+
+        # Python 3.12 venv/virtualenv no longer include setuptools and wheel by default, which
+        # breaks a number of these tests; ensure it's always present for 3.12+
+        if sys.version_info >= (3, 12):
+            subprocess.check_call([
+                os.path.join(tmpdir, 'bin/python'),
+                '-m',
+                'pip',
+                'install',
+                'setuptools',
+                'wheel',
+                '--upgrade'
+            ])
+
     except OSError as e:
-        py.test.skip("Cannot execute virtualenv: %s" % (e,))
+        pytest.skip("Cannot execute virtualenv: %s" % (e,))
 
     site_packages = None
     for dirpath, dirnames, filenames in os.walk(str(tmpdir)):
@@ -66,7 +84,7 @@ def really_run_setup_and_program(dirname, venv_dir_and_paths, python_snippet):
         remove(os.path.join(basedir, '__pycache__'))
     olddir = os.getcwd()
     python_f = udir.join('x.py')
-    python_f.write(py.code.Source(python_snippet))
+    python_f.write(textwrap.dedent(python_snippet))
     try:
         os.chdir(str(SNIPPET_DIR.join(dirname)))
         if os.name == 'nt':
@@ -77,7 +95,10 @@ def really_run_setup_and_program(dirname, venv_dir_and_paths, python_snippet):
         env = os.environ.copy()
         env['PYTHONPATH'] = paths
         subprocess.check_call((vp, 'setup.py', 'clean'), env=env)
-        subprocess.check_call((vp, 'setup.py', 'install'), env=env)
+        # there's a setuptools/easy_install bug that causes this to fail when the build/install occur together and
+        # we're in the same directory with the build (it tries to look up dependencies for itself on PyPI);
+        # subsequent runs will succeed because this test doesn't properly clean up the build- use pip for now.
+        subprocess.check_call((vp, '-m', 'pip', 'install', '.'), env=env)
         subprocess.check_call((vp, str(python_f)), env=env)
     finally:
         os.chdir(olddir)
@@ -156,7 +177,7 @@ class TestZIntegration(object):
         try:
             import setuptools
         except ImportError as e:
-            py.test.skip(str(e))
+            pytest.skip(str(e))
         orig_version = setuptools.__version__
         expecting_limited_api = not hasattr(sys, 'gettotalrefcount')
         try:
